# setup.py
from distutils.core import setup
setup(
    name='wplogin',
    packages=['wplogin'],
    version='0.0.1',
    description='A Simple WordPress Login Modul',
    long_description=open('README.txt').read(),
    author='GreenWorld Dev',
    author_email='coding@greenworlddev.com',
    license='MIT-License',
    keywords=['wp', 'wordpress', 'login']
)